Index: channels/sip/reqresp_parser.c
===================================================================
--- channels/sip/reqresp_parser.c	(revision 371989)
+++ channels/sip/reqresp_parser.c	(working copy)
@@ -1523,9 +1523,9 @@
  * item is found that is not supported, it is copied to the unsupported
  * out buffer.
  *
- * \param option list
+ * \param options list
  * \param unsupported out buffer (optional)
- * \param unsupported out buffer length (optional)
+ * \param unsupported_len out buffer length (optional)
  */
 unsigned int parse_sip_options(const char *options, char *unsupported, size_t unsupported_len)
 {
Index: apps/app_meetme.c
===================================================================
--- apps/app_meetme.c	(revision 371989)
+++ apps/app_meetme.c	(working copy)
@@ -1216,6 +1216,7 @@
  * \param dynamic Mark the newly created conference as dynamic
  * \param refcount How many references to mark on the conference
  * \param chan The asterisk channel
+ * \param test
  *
  * \return A pointer to the conference struct, or NULL if it wasn't found and
  *         make or dynamic were not set.
Index: apps/app_confbridge.c
===================================================================
--- apps/app_confbridge.c	(revision 371989)
+++ apps/app_confbridge.c	(working copy)
@@ -621,7 +621,7 @@
  * \brief Announce number of users in the conference bridge to the caller
  *
  * \param conference_bridge Conference bridge to peek at
- * \param (OPTIONAL) conference_bridge_user Caller
+ * \param conference_bridge_user Optional Caller
  *
  * \note if caller is NULL, the announcment will be sent to all participants in the conference.
  * \return Returns 0 on success, -1 if the user hung up
@@ -1258,7 +1258,7 @@
  * \brief Play number into the conference bridge
  *
  * \param conference_bridge The conference bridge to say the number into
- * \param number to say
+ * \param say_number number to say
  *
  * \retval 0 success
  * \retval -1 failure
Index: include/asterisk/app.h
===================================================================
--- include/asterisk/app.h	(revision 371989)
+++ include/asterisk/app.h	(working copy)
@@ -331,6 +331,9 @@
 
 /*!
  * \brief Set voicemail function callbacks
+ *
+ * \param copy_recording_to_vm_func, vm_index_to_foldername, vm_mailbox_snapshot_create
+ * \param vm_mailbox_snapshot_destroy, vm_msg_move, vm_msg_remove, vm_msg_forward, vm_msg_play
  * \param[in] has_voicemail_func set function pointer
  * \param[in] inboxcount_func set function pointer
  * \param[in] inboxcount2_func set function pointer
@@ -411,7 +414,10 @@
 /*!
  * \brief Determine number of new/old messages in a mailbox
  * \since 1.0
- * \param[in] mailbox Mailbox specification in the format mbox[@context][&mbox2[@context2]][...]
+ * \param[in] mailbox Mailbox specification in the format
+ * 	/code
+ *	 mbox[\@context][&mbox2[\@context2]][...]
+ *	/code
  * \param[out] newmsgs Number of messages in the "INBOX" folder.  Includes number of messages in the "Urgent" folder, if any.
  * \param[out] oldmsgs Number of messages in the "Old" folder.
  * \retval 0 Success
@@ -495,7 +501,7 @@
  * \param context The voicemail context for the mailbox
  * \param num_msgs The number of messages to move
  * \param oldfolder The folder from where messages should be moved
- * \param old_msg_nums The message IDs of the messages to move
+ * \param old_msg_ids The message IDs of the messages to move
  * \param newfolder The folder to which messages should be moved
  * new folder. This array must be num_msgs sized.
  *
@@ -557,10 +563,12 @@
 /*!
  * \brief Play a voicemail msg back on a channel.
  *
+ * \param chan
  * \param mailbox msg is in.
  * \param context of mailbox.
- * \param voicemail folder to look in.
- * \param message number in the voicemailbox to playback to the channel.
+ * \param folder voicemail folder to look in.
+ * \param msg_num message number in the voicemailbox to playback to the channel.
+ * \param cb
  *
  * \retval 0 success
  * \retval -1 failure
@@ -643,7 +651,7 @@
  * \param chan
  * \param file filename
  * \param fwd, rev, stop, pause, restart, skipms, offsetms
- * \param waitstream callback to invoke when fastforward or rewind occurrs.
+ * \param cb waitstream callback to invoke when fastforward or rewind occurrs.
  *
  * Before calling this function, set this to be the number
  * of ms to start from the beginning of the file.  When the function
Index: include/asterisk/bridging_features.h
===================================================================
--- include/asterisk/bridging_features.h	(revision 371989)
+++ include/asterisk/bridging_features.h	(working copy)
@@ -197,7 +197,7 @@
  * \param dtmf DTMF string to be activated upon
  * \param callback Function to execute upon activation
  * \param hook_pvt Unique data
- * \param Optional destructor callback for hook_pvt data
+ * \param destructor Optional destructor callback for hook_pvt data
  *
  * \retval 0 on success
  * \retval -1 on failure
@@ -226,9 +226,9 @@
 /*! \brief Set a callback on the features structure to receive talking notifications on.
  *
  * \param features Bridge features structure
- * \param talker_cb, Callback function to execute when talking events occur in the bridge core.
+ * \param talker_cb Callback function to execute when talking events occur in the bridge core.
  * \param pvt_data Optional unique data that will be passed with the talking events.
- * \param Optional destructor callback for pvt data.
+ * \param talker_destructor Optional destructor callback for pvt data.
  *
  * \retval 0, success
  * \retval -1, failure
Index: include/asterisk/sip_api.h
===================================================================
--- include/asterisk/sip_api.h	(revision 371989)
+++ include/asterisk/sip_api.h	(working copy)
@@ -29,9 +29,10 @@
 /*!
  * \brief Send a customized SIP INFO request
  *
+ * \param chan Channel
  * \param headers The headers to add to the INFO request
  * \param content_type The content type header to add
- * \param conten The body of the INFO request
+ * \param content The body of the INFO request
  * \param useragent_filter If non-NULL, only send the INFO if the
  * recipient's User-Agent contains useragent_filter as a substring
  *
Index: include/asterisk/res_odbc.h
===================================================================
--- include/asterisk/res_odbc.h	(revision 371989)
+++ include/asterisk/res_odbc.h	(working copy)
@@ -104,9 +104,11 @@
  * \brief Retrieves a connected ODBC object
  * \param name The name of the ODBC class for which a connection is needed.
  * \param flags One or more of the following flags:
- * \li RES_ODBC_SANITY_CHECK Whether to ensure that a connection is valid before returning the handle.  Usually unnecessary.
- * \li RES_ODBC_INDEPENDENT_CONNECTION Return a handle which is independent from all others.  Usually used when starting a transaction.
- * \li RES_ODBC_CONNECTED Only return a connected handle.  Intended for use with peers which use idlecheck, which are checked periodically for reachability.
+ *	\li RES_ODBC_SANITY_CHECK Whether to ensure that a connection is valid before returning the handle.  Usually unnecessary.
+ *	\li RES_ODBC_INDEPENDENT_CONNECTION Return a handle which is independent from all others.  Usually used when starting a transaction.
+ *	\li RES_ODBC_CONNECTED Only return a connected handle.  Intended for use with peers which use idlecheck, which are checked periodically for reachability.
+ * \param  file, function, lineno
+ *
  * \return ODBC object
  * \retval NULL if there is no connection available with the requested name.
  *
Index: include/asterisk/localtime.h
===================================================================
--- include/asterisk/localtime.h	(revision 371989)
+++ include/asterisk/localtime.h	(working copy)
@@ -75,7 +75,6 @@
  * \param len Size of the chunk of memory buf.
  * \param format A string specifying the format of time to be placed into buf.
  * \param tm Pointer to the broken out time to be used for the format.
- * \param locale Text string specifying the locale to be used for language strings.
  * \retval An integer value specifying the number of bytes placed into buf or -1 on error.
  */
 int ast_strftime(char *buf, size_t len, const char *format, const struct ast_tm *tm);
@@ -87,7 +86,6 @@
  * \param s A string specifying some portion of a date and time.
  * \param format The format in which the string, s, is expected.
  * \param tm The broken-out time structure into which the parsed data is expected.
- * \param locale Text string specifying the locale to be used for language strings.
  * \retval A pointer to the first character within s not used to parse the date and time.
  */
 char *ast_strptime(const char *s, const char *format, struct ast_tm *tm);
Index: main/tdd.c
===================================================================
--- main/tdd.c	(revision 371989)
+++ main/tdd.c	(working copy)
@@ -281,8 +281,9 @@
 } while(0);
 
 /*! Generate TDD hold tone
- * \param buf Result buffer
- * \todo How big should this be??? */
+ * \param outbuf, buf Result buffer
+ * \todo How big should this be?
+ */
 int tdd_gen_holdtone(unsigned char *buf)
 {
 	int bytes = 0;
Index: main/acl.c
===================================================================
--- main/acl.c	(revision 371989)
+++ main/acl.c	(working copy)
@@ -371,7 +371,7 @@
  * \param netmask The netmask configured in the host access rule.
  * \param result The resultant address after applying the netmask to the given address
  * \retval 0 Successfully applied netmask
- * \reval -1 Failed to apply netmask
+ * \retval -1 Failed to apply netmask
  */
 static int apply_netmask(const struct ast_sockaddr *addr, const struct ast_sockaddr *netmask,
 		struct ast_sockaddr *result)
Index: main/ccss.c
===================================================================
--- main/ccss.c	(revision 371989)
+++ main/ccss.c	(working copy)
@@ -568,6 +568,8 @@
  * \intenral
  * \brief lookup the ast_device_state mapped to cc_state
  *
+ * \param state
+ *
  * \return the correponding DEVICE STATE from the cc_state_to_devstate_map
  * when passed an internal state.
  */
@@ -1638,7 +1640,7 @@
 	 *
 	 * \details
 	 * This serves mainly as a key when searching for a particular dialstring.
-	 * For instance, let's say that we have called device SIP/400@somepeer. This
+	 * For instance, let's say that we have called device SIP/400\@somepeer. This
 	 * device offers call completion, but then due to some unforeseen circumstance,
 	 * this device backs out and makes CC unavailable. When that happens, we need
 	 * to find the dialstring that corresponds to that device, and we use the
Index: main/sha1.c
===================================================================
--- main/sha1.c	(revision 371989)
+++ main/sha1.c	(working copy)
@@ -336,7 +336,7 @@
 /*!
  * \brief This helper function finishes off the digest calculations.
  * \param context [in/out]  The context to pad.
- * \param Pad_byte [in]  The last byte to add to the message block
+ * \param Pad_Byte [in]  The last byte to add to the message block
  *     before the 0-padding and length.  This will contain the last
  *     bits of the message followed by another single bit.  If the
  *     message was an exact multiple of 8-bits long, Pad_Byte will
@@ -359,7 +359,7 @@
 /*!
  * \brief Pad message to be 512 bits.
  * \param context [in/out]  The context to pad.
- * \param Pad_byte [in]  Last padding byte.
+ * \param Pad_Byte [in]  Last padding byte.
  *
  *  According to the standard, the message must be padded to the next
  *  even multiple of 512 bits.  The first padding bit must be a '1'.
Index: main/strings.c
===================================================================
--- main/strings.c	(revision 371989)
+++ main/strings.c	(working copy)
@@ -70,7 +70,7 @@
 		}
 		/*
 		 * Ask vsnprintf how much space we need. Remember that vsnprintf
-		 * does not count the final <code>'\0'</code> so we must add 1.
+		 * does not count the final <code>'\\0'</code> so we must add 1.
 		 */
 		va_copy(aq, ap);
 		res = vsnprintf((*buf)->__AST_STR_STR + offset, (*buf)->__AST_STR_LEN - offset, fmt, aq);
Index: res/res_xmpp.c
===================================================================
--- res/res_xmpp.c	(revision 371989)
+++ res/res_xmpp.c	(working copy)
@@ -22,7 +22,7 @@
  *
  * \author Joshua Colp <jcolp@digium.com>
  *
- * \extref Iksemel http://code.google.com/p/iksemel/
+ * Iksemel http://code.google.com/p/iksemel/
  *
  * A reference module for interfacting Asterisk directly as a client or component with
  * an XMPP/Jabber compliant server.
@@ -1017,6 +1017,7 @@
  * \param client the configured XMPP client we use to connect to a XMPP server
  * \param node_type the type of node to create
  * \param name the name of the node to create
+ * \param collection_name
  * \return void
  */
 static void xmpp_pubsub_create_node(struct ast_xmpp_client *client, const char *node_type, const
@@ -1078,6 +1079,7 @@
 /*!
  * \brief Create a PubSub leaf node.
  * \param client the configured XMPP client we use to connect to a XMPP server
+ * \param collection_name
  * \param leaf_name The name to use for this collection
  * \return void.
  */
@@ -1090,8 +1092,10 @@
 /*!
  * \brief Publish MWI to a PubSub node
  * \param client the configured XMPP client we use to connect to a XMPP server
- * \param device the name of the device whose state to publish
- * \param device_state the state to publish
+ * \param mailbox The Mailbox
+ * \param context The Context
+ * \param oldmsgs Old messages
+ * \param newmsgs New Messages
  * \return void
  */
 static void xmpp_pubsub_publish_mwi(struct ast_xmpp_client *client, const char *mailbox,
@@ -1278,6 +1282,7 @@
 /*!
  * \brief Callback for handling PubSub events
  * \param data void pointer to ast_xmpp_client structure
+ * \param pak A pak
  * \return IKS_FILTER_EAT
  */
 static int xmpp_pubsub_handle_event(void *data, ikspak *pak)
Index: res/res_jabber.c
===================================================================
--- res/res_jabber.c	(revision 371989)
+++ res/res_jabber.c	(working copy)
@@ -23,7 +23,7 @@
  * References:
  * - http://www.xmpp.org - The XMPP standards foundation
  *
- * \extref Iksemel http://code.google.com/p/iksemel/
+ * Iksemel http://code.google.com/p/iksemel/
  *
  * \todo If you unload this module, chan_gtalk/jingle will be dead. How do we handle that?
  * \todo Dialplan applications need RETURN variable, like JABBERSENDSTATUS
@@ -3303,6 +3303,7 @@
 /*!
  * \brief Callback for handling PubSub events
  * \param data void pointer to aji_client structure
+ * \param pak A pak
  * \return IKS_FILTER_EAT
  */
 static int aji_handle_pubsub_event(void *data, ikspak *pak)
@@ -3475,8 +3476,10 @@
 /*!
  * \brief Publish MWI to a PubSub node
  * \param client the configured XMPP client we use to connect to a XMPP server
- * \param device the name of the device whose state to publish
- * \param device_state the state to publish
+ * \param mailbox The mailbox
+ * \param context The context
+ * \param oldmsgs Old messages
+ * \param newmsgs New messages
  * \return void
  */
 static void aji_publish_mwi(struct aji_client *client, const char *mailbox,
@@ -3832,6 +3835,7 @@
 /*!
  * \brief Create a PubSub leaf node.
  * \param client the configured XMPP client we use to connect to a XMPP server
+ * \param collection_name The name to use for this collection
  * \param leaf_name The name to use for this collection
  * \return void.
  */
@@ -3846,6 +3850,7 @@
  * \param client the configured XMPP client we use to connect to a XMPP server
  * \param node_type the type of node to create
  * \param name the name of the node to create
+ * \param collection_name The name to use for this collection
  * \return iks*
  */
 static iks* aji_create_pubsub_node(struct aji_client *client, const char *node_type, const
Index: README
===================================================================
--- README	(revision 371989)
+++ README	(working copy)
@@ -36,7 +36,7 @@
   In addition you'll find lots of information compiled by the Asterisk
 community on this Wiki:
 
-           http://www.voip-info.org/wiki-Asterisk
+           http://wiki.asterisk.org
 
   There is a book on Asterisk published by O'Reilly under the Creative Commons
 License. It is available in book stores as well as in a downloadable version on
